OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die externe Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Externe Freigabe",
    "Remote share password" : "Passwort für die externe Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Externe Freigabe hinzufügen",
    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "Couldn't establish a federated share." : "Federated-Share konnte nicht aufgebaut werden",
    "Couldn't establish a federated share, maybe the password was wrong." : "Federated-Share konnte nicht aufgebaut werden, da eventuell das Passwort falsch ist.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Anfrage für Cloud-übergreifende Freigabe war erfolgreich. Sie erhalten eine Einladung. Bitte prüfen Sie Ihre Benachrichtigungen. ",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Federated-Share konnte nicht aufgebaut werden, da der Zielserver eine zu alte Version verwendet (Nextcloud <=9).",
    "It is not allowed to send federated group shares from this server." : "Das Versenden einer Cloud-übergreifenden Freigabe ist von diesem Server aus nicht zugelassen.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Freigeben von %1$s ist fehlgeschlagen, da dieses Element schon mit dem Konto %2$s geteilt wurde",
    "Not allowed to create a federated share to the same account" : "Das Erstellen einer Federated-Cloud-Freigabe mit dem gleichen Konto ist nicht erlaubt",
    "Federated shares require read permissions" : "Federated-Shares benötigen Leseberechtigungen",
    "File is already shared with %s" : "Datei wird bereits geteilt mit %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Freigabe von %1$s fehlgeschlagen, da %2$s nicht gefunden wurde. Möglicherweise ist der Server nicht erreichbar oder nutzt ein selbst zertifiziertes Zertifikat.",
    "Could not find share" : "Freigabe konnte nicht gefunden werden",
    "Federated sharing" : "Federated-Sharing",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Sie haben {share} als externe Freigabe von {user} (im Auftrag von {behalf}) erhalten",
    "You received {share} as a remote share from {user}" : "Sie haben {share} als externe Freigabe von {user} erhalten",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Sharing" : "Teilen",
    "Federated file sharing" : "Federated Datei-Freigabe",
    "Provide federated file sharing across servers" : "Bietet Cloud-übergreifende Datei-Freigaben",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Legt fest, wie Personen zwischen Servern teilen können. Dies gilt auch für Freigaben zwischen Personen auf diesem Server, wenn sie Federated-Sharing verwenden.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Personen auf diesem Server das Senden von Freigaben an andere Server erlauben (Diese Option ermöglicht auch den WebDAV-Zugriff auf öffentliche Freigaben)",
    "Allow people on this server to receive shares from other servers" : "Ermöglichen Sie Personen auf diesem Server, Freigaben von anderen Servern zu erhalten",
    "Allow people on this server to send shares to groups on other servers" : "Ermöglichen Sie Personen auf diesem Server, Freigaben an Gruppen auf anderen Servern zu senden",
    "Allow people on this server to receive group shares from other servers" : "Ermöglichen Sie Personen auf diesem Server, Gruppenfreigaben von anderen Servern zu erhalten",
    "Search global and public address book for people" : "Durchsuche globales und öffentliches Adressbuch nach Personen",
    "Allow people to publish their data to a global and public address book" : "Erlaube Personen, ihre Daten in einem globalen und öffentlichen Adressbuch zu veröffentlichen",
    "Unable to update federated files sharing config" : "Einstellungen zum Federated-Teilen konnten nicht aktualisiert werden",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Sie können mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Geben Sie einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
    "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
    "Share it so your friends can share files with you:" : "Teilen Sie es, so dass Ihre Freunde Dateien mit Ihnen teilen können:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Zu Ihrer Webseite hinzufügen",
    "Share with me via Nextcloud" : "Teilen Sie mit mir über Nextcloud",
    "HTML Code:" : "HTML-Code:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID, siehe {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID",
    "Cloud ID copied to the clipboard" : "Cloud-ID wurde in die Zwischenablage kopiert",
    "Copy to clipboard" : "In die Zwischenablage kopieren",
    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
    "Copied!" : "Kopiert!",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Freigabe von %1$s fehlgeschlagen, da dieses Element schon mit dem Benutzer %2$s geteilt wird.",
    "Not allowed to create a federated share with the same user" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Legt fest, wie Personen zwischen Servern teilen können. Dies gilt auch für Freigaben zwischen Benutzern auf diesem Server, wenn sie die Federated-Sharing verwenden.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben (Diese Option ermöglicht auch den WebDAV-Zugriff auf öffentliche Freigaben)",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Allow users on this server to send shares to groups on other servers" : "Ermöglichen Sie Nutzern dieses Servers, Freigaben an Gruppen auf anderen Servern zu senden",
    "Allow users on this server to receive group shares from other servers" : "Ermöglichen Sie Nutzern dieses Servers, Gruppen-Freigaben von anderen Servern zu erhalten",
    "Search global and public address book for users" : "Durchsuche globales und öffentliches Adressbuch nach Nutzern",
    "Allow users to publish their data to a global and public address book" : "Erlaube Benutzern, ihre Daten in einem globalen und öffentlichen Adressbuch zu veröffentlichen"
},
"nplurals=2; plural=(n != 1);");
